import * as react_jsx_runtime from 'react/jsx-runtime';
import * as React from 'react';
import React__default, { ReactNode, MutableRefObject } from 'react';

type labelPosition = 'top' | 'left';
interface SelectProps<T> {
    data: T[];
    displayKey: keyof T;
    valueKey: keyof T;
    label: string;
    value?: string;
    onSelect: (e: T) => void;
    labelPosition?: labelPosition;
    useLabel?: boolean;
    backgroundClass?: string;
    textColorClass?: string;
    fillClass?: string;
    hoverClass?: string;
}
declare const Select: <T>({ data, displayKey, valueKey, label, value, onSelect, labelPosition, useLabel, backgroundClass, textColorClass, fillClass, hoverClass, }: SelectProps<T>) => react_jsx_runtime.JSX.Element;

type TablePluginType = 'cellEditingPlugin' | 'rowEditingPlugin';

type FormatterType = typeof numberFormatter | typeof imageFormatter | null;
declare const numberFormatter: (input: string | number | boolean) => string;
declare const imageFormatter: (input: string) => react_jsx_runtime.JSX.Element;

declare const ChevronDown: ({ height, width, fill, stroke, className, onClick, style, }: IconProps) => react_jsx_runtime.JSX.Element;

declare const GearIcon: ({ height, width, fill, stroke, className, onClick, }: IconProps) => react_jsx_runtime.JSX.Element;

declare const TriangleDown: ({ height, width, fill, stroke, className, onClick, style, }: IconProps) => react_jsx_runtime.JSX.Element;

declare const HourIcon: ({ height, width, fill, className }: IconProps) => react_jsx_runtime.JSX.Element;

declare const SalesIcon: ({ height, width, fill, className }: IconProps) => react_jsx_runtime.JSX.Element;

declare const ReportsIcon: ({ height, width, fill, className }: IconProps) => react_jsx_runtime.JSX.Element;

declare const Clipboard: ({ height, width, fill, className, onClick, }: IconProps) => react_jsx_runtime.JSX.Element;

type IconType = typeof HourIcon | typeof ReportsIcon | typeof SalesIcon;
interface IconProps {
    height: number;
    width: number;
    fill: string;
    stroke: string;
    strokeWidth?: number;
    className?: string;
    onClick?: (e: React__default.MouseEvent<SVGGElement>) => void;
    style?: React__default.CSSProperties;
}
type ITableHeaderAlign = 'left' | 'center' | 'right';
type IDataType = 'string' | 'number' | 'boolean' | 'date';
interface ITableHeader {
    column: string;
    alias: string;
    visible: boolean;
    renderer: () => void;
    width: number | 'flex';
    align: ITableHeaderAlign;
    formatter: FormatterType;
    dataType: IDataType;
    editable?: boolean;
    editor?: null;
}

interface ITable<T> {
    data: T[];
    headers: ITableHeader[];
    backgroundColorClass?: string;
    backgroundColorStyle?: string;
    textColorClass?: string;
    textColorStyle?: string;
    footerBackgroundClass?: string;
    footerBackgroundColorStyle?: string;
    footerTextColorClass?: string;
    footerTextColorStyle?: string;
    hoverClass?: string;
    striped?: boolean;
    stripeEvenClass?: string;
    stripeOddClass?: string;
    textColorClass2?: string;
    tablePluginType?: TablePluginType;
}
declare const Table: <T>({ data, headers, backgroundColorClass, backgroundColorStyle, textColorClass, textColorStyle, footerBackgroundClass, footerBackgroundColorStyle, footerTextColorClass, footerTextColorStyle, hoverClass, striped, stripeEvenClass, stripeOddClass, textColorClass2, tablePluginType, }: ITable<T>) => react_jsx_runtime.JSX.Element;

type ToastType = 'success' | 'error' | 'info' | 'warning';
type ToastAnimationType = 'slide' | 'fade' | 'bounce' | 'zoom' | 'flip' | 'rotate';
type ToastPosition = 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';

type ToastProviderProps = {
    children?: ReactNode;
    autoClose?: boolean;
    duration?: number;
    position?: ToastPosition;
    recentOnTop?: boolean;
};
interface ToastOptions {
    useIcon?: boolean;
    autoClose?: boolean;
    duration?: number;
    animationType?: ToastAnimationType;
}
interface ToastProps {
    id: string;
    type: ToastType;
    message: string;
    options?: ToastOptions;
}
interface ToastContextValue {
    addToast: (type: ToastType, message: string, options?: ToastOptions) => void;
    removeToast: (id: string) => void;
}
interface ToastContainerProps {
    toasts: ToastProps[];
    removeToast: (id: string) => void;
    position: ToastPosition;
}

declare const useToast: () => {
    success: (message: string, options?: ToastOptions) => void;
    error: (message: string, options?: ToastOptions) => void;
    warning: (message: string, options?: ToastOptions) => void;
    info: (message: string, options?: ToastOptions) => void;
    warn: (message: string, options?: ToastOptions) => void;
};

interface ToastCmpProps {
    toast: ToastProps;
    onClick: () => void;
    position: ToastPosition;
}
declare const Toast: ({ toast, onClick, position }: ToastCmpProps) => react_jsx_runtime.JSX.Element;

declare const ToastContext: React.Context<ToastContextValue | undefined>;

declare const ToastProvider: ({ children, autoClose, duration, position, recentOnTop, }: ToastProviderProps) => react_jsx_runtime.JSX.Element;

declare const ToastContainer: ({ toasts, removeToast, position, }: ToastContainerProps) => react_jsx_runtime.JSX.Element;

type CollapseType = 'collapsed' | 'expanded';
interface CodeCellProps {
    codeGenerator: () => string;
    title: string;
    expandedState?: CollapseType;
}
declare const CodeCell: ({ codeGenerator, title, expandedState, }: CodeCellProps) => react_jsx_runtime.JSX.Element;

type NodeType = object | Function | string | number | boolean | null;
type JsonTreeViewProps = {
    data: Record<string, NodeType>;
    backgroundColorClass?: string;
    textColorClass?: string;
    isDefaultExpanded?: boolean;
    className?: string;
    style?: React__default.CSSProperties;
};
declare const JsonTreeView: ({ data, backgroundColorClass, textColorClass, isDefaultExpanded, }: JsonTreeViewProps) => react_jsx_runtime.JSX.Element;

type Header = {
    title: string;
    type: 'number' | 'string' | 'boolean' | 'date' | 'money';
    formatter: (value: string | number | boolean) => string;
    alias: string;
    visible: boolean;
    order: number;
    className?: string;
};

interface PivotTableProps<T extends object> {
    data: T[];
    headers: Header[];
    usePivot?: boolean;
    setUsePivot?: (usePivot: boolean) => void;
    demoMode?: boolean;
}
declare const PivotTable: <T extends object>({ data, headers, usePivot, setUsePivot, demoMode, }: PivotTableProps<T>) => react_jsx_runtime.JSX.Element;

declare const formatCurrency: (price: string) => string;
declare const formatDate: (input: string) => string;

interface InputProps {
    text: string;
    setText: (str: string) => void;
    setIsSearching: (bool: boolean) => void;
    setIsClicked: (bool: boolean) => void;
    width?: number;
}
declare const Input: ({ text, setText, setIsSearching, width, setIsClicked }: InputProps) => react_jsx_runtime.JSX.Element;

declare const Radio: () => react_jsx_runtime.JSX.Element;

declare const Checkbox: () => react_jsx_runtime.JSX.Element;

interface SplitContainerProps {
    firstChild: React__default.ReactNode;
    secondChild: React__default.ReactNode;
    direction: 'horizontal' | 'vertical';
    parentWidth?: number;
    dividerColor?: string;
}
declare const SplitContainer: ({ firstChild, secondChild, direction, parentWidth, dividerColor, }: SplitContainerProps) => react_jsx_runtime.JSX.Element;

declare const DiffEditor: () => react_jsx_runtime.JSX.Element;

declare const useWindowSize: () => {
    width: number;
    height: number;
};

interface CodeEditorProps {
    code: string;
    setCode: (code: string) => void;
    currentLine: number | null;
    delay?: number;
    caretClass?: string;
    caretStyleColor?: string;
    backgroundClass?: string;
    textColorClass?: string;
    backgroundStyleColor?: string;
    textStyleColor?: string;
    getCode?: () => string;
}
declare const CodeEditor: ({ code, setCode, currentLine, delay, caretClass, caretStyleColor, backgroundClass, textColorClass, backgroundStyleColor, textStyleColor, getCode, }: CodeEditorProps) => react_jsx_runtime.JSX.Element;

interface DebuggerEnvironmentProps {
    getCode?: () => void;
}
declare const DebuggerEnvironment: ({ getCode }: DebuggerEnvironmentProps) => react_jsx_runtime.JSX.Element;

interface DebuggerIconProps {
    stroke: string;
    height: number;
    width: number;
    strokeWidth: number;
}
declare const DebuggerIcon: ({ height, width, stroke, strokeWidth, }: DebuggerIconProps) => react_jsx_runtime.JSX.Element;

type TooltipProps = {
    content: string;
    placement?: 'top' | 'bottom' | 'left' | 'right';
    children: React__default.ReactNode;
};
declare const Tooltip: React__default.FC<TooltipProps>;

type SidebarDataProps = {
    id: number;
    name: string;
    children?: SidebarDataProps[];
    icon?: IconType;
};
interface SidebarProps {
    data: SidebarDataProps[];
    title?: string;
    maxWidth?: number;
}
declare const Sidebar: ({ data, title, maxWidth }: SidebarProps) => react_jsx_runtime.JSX.Element;

type SortDirection = 'asc' | 'desc';
declare const sort: <T>(arr: T[], field: keyof T, direction: SortDirection | undefined, header: ITableHeader) => T[];

interface TooltipContextType {
    showTooltip: (content: string, x: number, y: number) => void;
    hideTooltip: () => void;
}
declare const TooltipProvider: ({ children }: {
    children: ReactNode;
}) => react_jsx_runtime.JSX.Element;
declare const useTooltip: () => TooltipContextType;

type Handler = (e: MouseEvent | TouchEvent) => void;
declare const useClickOutside: <T extends HTMLElement>(handler: Handler) => MutableRefObject<T | null>;

declare const isObject: (obj: any) => "" | "{}";
declare const isArray: (arr: any) => string;
declare const isFunction: (func: any) => any;

export { Checkbox, ChevronDown, Clipboard, CodeCell, type CodeCellProps, CodeEditor, DebuggerEnvironment, DebuggerIcon, DiffEditor, GearIcon, type Header, HourIcon, type ITableHeader, type IconProps, Input, JsonTreeView, PivotTable, Radio, ReportsIcon, SalesIcon, Select, Sidebar, type SidebarDataProps, SplitContainer, Table, type TablePluginType, Toast, ToastContainer, ToastContext, type ToastPosition, ToastProvider, type ToastProviderProps, type ToastType, Tooltip, TooltipProvider, TriangleDown as TriangleRight, formatCurrency, formatDate, imageFormatter, isArray, isFunction, isObject, numberFormatter, sort, useClickOutside, useToast, useTooltip, useWindowSize };
